@@ -32,10 +32,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x030b00
-pyqt_version_str = "3.11"
+pyqt_version = 0x030d00
+pyqt_version_str = "3.13"
 
-sip_min_v3_version = 0x030a01
+sip_min_v3_version = 0x030a02
 sip_min_v4_version = 0x040000
 
 pyqt_modules = ["qt"]
@@ -43,6 +43,7 @@ qt_sip_flags = []
 qtext_sip_flags = []
 qtpe_sip_flags = []
 qsci_version = 0
+disabled_classes = []
 
 if sys.platform == "win32":
     qsci_define = "QEXTSCINTILLA_DLL"
@@ -68,6 +69,7 @@ opt_concat = 0
 opt_split = 1
 opt_releasegil = 0
 opt_tracing = 0
+opt_verbose = 0
 
 
 def usage(rcode = 2):
@@ -76,7 +78,7 @@ def usage(rcode = 2):
     rcode is the return code passed back to the calling process.
     """
     print "Usage:"
-    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-g] [-j #] [-k] [-n dir] [-o dir] [-r] [-s] [-u] [-v dir]"
+    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-g] [-j #] [-k] [-n dir] [-o dir] [-r] [-s] [-u] [-v dir] [-w]"
     print "where:"
     print "    -h      display this help message"
     print "    -a tag  explicitly enable the qtpe module"
@@ -92,6 +94,7 @@ def usage(rcode = 2):
     print "    -s      QScintilla is a static library and not a DLL (Windows only)"
     print "    -u      build with debugging symbols"
     print "    -v dir  where the PyQt .sip files will be installed [default %s]" % opt_pyqtsipdir
+    print "    -w      don't suppress compiler output during configuration"
 
     sys.exit(rcode)
 
@@ -100,6 +103,7 @@ def inform_user():
     """Tell the user the option values that are going to be used.
     """
     sipconfig.inform("These PyQt modules will be built: %s." % string.join(pyqt_modules))
+    sipconfig.inform("Support for these Qt classes has been disabled: %s." % string.join(disabled_classes))
     sipconfig.inform("The PyQt modules will be installed in %s." % opt_pyqtmoddir)
     sipconfig.inform("The PyQt .sip files will be installed in %s." % opt_pyqtsipdir)
 
@@ -129,6 +133,9 @@ def create_config(module, template):
         "pyqt_qt_sip_flags":  qt_sip_flags
     }
 
+    if "qtaxcontainer" in pyqt_modules:
+        content["pyqt_qtaxcontainer_sip_flags"] = qt_sip_flags
+
     if "qtcanvas" in pyqt_modules:
         content["pyqt_qtcanvas_sip_flags"] = qt_sip_flags
 
@@ -202,7 +209,23 @@ def compile_qt_program(name, define=None, include_dir=None, lib_dir=None, lib=No
     except OSError:
         pass
 
-    os.system(build)
+    if not opt_verbose and hasattr(os, "popen4"):
+        fin, fout = os.popen4(build)
+
+        # Read stdout and stderr until there is no more output.
+        lout = fout.readline()
+        while lout:
+            lout = fout.readline()
+
+        fin.close()
+        fout.close()
+
+        try:
+            os.wait()
+        except AttributeError:
+            pass
+    else:
+        os.system(build)
 
     if not os.access(exe, os.X_OK):
         return None
@@ -298,7 +321,7 @@ def check_plugin(cname, incfile):
     cname is the name of the class.
     incfile is the name of the include file needed for the test.
     """
-    sipconfig.inform("Checking to see if the %s class is a plugin..." % cname)
+    sipconfig.inform("Checking to see if the %s class is built in..." % cname)
 
     return check_class(incfile, cname + "()")
 
@@ -309,7 +332,7 @@ def create_features_file(name):
     name is the name of the features file in the current directory.
     """
     # The features that a given Qt configuration may or may not support.  Note
-    # that STYLE_WINDOWSXP requires special handling.
+    # that STYLE_WINDOWSXP and ASSISTANTCLIENT require special handling.
     flist = ["ACTION", "CLIPBOARD", "CODECS", "COLORDIALOG", "DATASTREAM",
              "DIAL", "DNS", "DOM", "DRAGANDDROP", "ICONVIEW", "IMAGE_TEXT",
              "INPUTDIALOG", "FILEDIALOG", "FONTDATABASE", "FONTDIALOG",
@@ -360,6 +383,13 @@ int main(int argc,char **argv)
 #endif
 """ % (feat, feat))
 
+    # Disable QAssistantClient for the Professional Edition.
+    if "QAssistantClient" in disabled_classes:
+        f.write(
+"""
+    fprintf(fp,"-x Qt_ASSISTANTCLIENT\\n");
+""")
+
     f.write(
 """
     fclose(fp);
@@ -388,13 +418,15 @@ int main(int argc,char **argv)
                ("STYLE_MOTIFPLUS", "qmotifplusstyle.h", "QMotifPlusStyle"),
                ("STYLE_PLATINUM",  "qplatinumstyle.h",  "QPlatinumStyle"),
                ("STYLE_SGI",       "qsgistyle.h",       "QSGIStyle"),
-               ("STYLE_WINDOWS",   "qwindowsstyle.h",   "QWindowsStyle")];
+               ("STYLE_WINDOWSXP", "qwindowsxpstyle.h", "QWindowsXPStyle"),
+               ("STYLE_WINDOWS",   "qwindowsstyle.h",   "QWindowsStyle")]
 
     f = open(name, "a")
 
     for (feat, incfile, cname) in plugins:
         if not check_plugin(cname, incfile):
             f.write("-x Qt_%s\n" % feat)
+            disabled_classes.append(cname)
 
     f.close()
 
@@ -477,7 +509,9 @@ def set_sip_flags():
         qscitags = {
             0x010100: "QScintilla_1_0",
             0x010200: "QScintilla_1_1",
-            0x020000: "QScintilla_1_2"
+            0x010300: "QScintilla_1_2",
+            0x010400: "QScintilla_1_3",
+            0x020000: "QScintilla_1_4"
         }
 
         qtext_sip_flags.append("-t")
@@ -699,7 +733,7 @@ def create_makefiles():
 
         sipconfig.inform("Creating pyuic Makefile...")
 
-        if prof:
+        if prof or "qtxml" not in pyqt_modules:
             buildfile= "pyuic-prof.sbf"
 
             for xml in ("qdom.cpp", "qxml.cpp"):
@@ -720,7 +754,7 @@ def create_makefiles():
         makefile.extra_defines.append("UIC")
         makefile.extra_defines.append("QT_INTERNAL_XML")
 
-        if prof:
+        if prof or "qtxml" not in pyqt_modules:
             makefile.extra_defines.append("QT_MODULE_XML")
 
         if sipcfg.qt_version < 0x030100:
@@ -731,7 +765,7 @@ def create_makefiles():
 
         sipconfig.inform("Creating pylupdate Makefile...")
 
-        if prof:
+        if prof or "qtxml" not in pyqt_modules:
             buildfile= "pylupdate-prof.sbf"
 
             shutil.copyfile(sipcfg.qt_dir + "/src/xml/qxml.cpp", "pylupdate3/qxml.cpp")
@@ -750,7 +784,7 @@ def create_makefiles():
 
         makefile.extra_defines.append("QT_INTERNAL_XML")
 
-        if prof:
+        if prof or "qtxml" not in pyqt_modules:
             makefile.extra_defines.append("QT_MODULE_XML")
 
         makefile.generate()
@@ -789,13 +823,13 @@ def main(argv):
     argv is the list of command line arguments.
     """
     try:
-        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:gj:kn:o:rsuv:")
+        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:gj:kn:o:rsuv:w")
     except getopt.GetoptError:
         usage()
 
     global opt_pyqtbindir, opt_pyqtmoddir, opt_pyqtsipdir
     global opt_qtpetag, opt_static, opt_debug, opt_concat, opt_releasegil
-    global opt_split, opt_tracing
+    global opt_split, opt_tracing, opt_verbose
     global opt_qsciincdir, opt_qscilibdir, qsci_define
 
     for opt, arg in optlist:
@@ -830,6 +864,8 @@ def main(argv):
             opt_debug = 1
         elif opt == "-v":
             opt_pyqtsipdir = arg
+        elif opt == "-w":
+            opt_verbose = 1
 
     if args:
         usage()
@@ -863,27 +899,36 @@ def main(argv):
     check_module("qtgl", "qgl.h", "QGLWidget()", opengl=1)
 
     if sipcfg.qt_version >= 0x030000:
-        check_module("qtsql", "qsql.h", "QSql()")
         check_module("qtui", "qwidgetfactory.h", "QWidgetFactory()", lib="qui")
 
+        if sipcfg.qt_edition in ("enterprise", "free"):
+            check_module("qtsql", "qsql.h", "QSql()")
+
+            if sys.platform == "win32" and sipcfg.sip_version >= 0x040200:
+                check_module("qtaxcontainer", "qaxobject.h", "QAxObject()", lib="qaxcontainer")
+
     if qsci_version:
         check_module("qtext", "qextscintillabase.h", "QextScintillaBase()", define=qsci_define, include_dir=opt_qsciincdir, lib_dir=opt_qscilibdir, lib="qscintilla")
 
     if opt_qtpetag:
         pyqt_modules.append("qtpe")
 
+    qtmod_lib = ""
+
+    if sipcfg.qt_version >= 0x030100:
+        sipconfig.inform("Checking to see if the QAssistantClient class is available...")
+
+        if check_class("qassistantclient.h", "QAssistantClient(\"foo\")", lib="qassistantclient"):
+            qtmod_lib = "qassistantclient"
+        else:
+            disabled_classes.append("QAssistantClient")
+
     # Set the SIP platform, version and feature flags.
     set_sip_flags()
 
     # Tell the user what's been found.
     inform_user()
 
-    # Generate the code.
-    if sipcfg.qt_version >= 0x030000:
-        qtmod_lib = "qassistantclient"
-    else:
-        qtmod_lib = ""
-
     # For SIP v3 on AIX we need an extra linker flag for the qt module as the
     # table of contents (TOC) is greater than 64KB.
     if sipcfg.sip_version < 0x040000 and string.find(sys.platform, "aix") == 0:
@@ -891,6 +936,7 @@ def main(argv):
     else:
         qtmod_lflags = ""
 
+    # Generate the code.
     generate_code("qt", extra_lflags=qtmod_lflags, extra_lib=qtmod_lib)
 
     if "qtext" in pyqt_modules:
@@ -908,6 +954,9 @@ def main(argv):
     if "qtui" in pyqt_modules:
         generate_code("qtui", imports=["qt"], extra_lib="qui")
 
+    if "qtaxcontainer" in pyqt_modules:
+        generate_code("qtaxcontainer", imports=["qt"], extra_lib="qaxcontainer")
+
     # The rest don't need special handling.
     for m in ("qtcanvas", "qtnetwork", "qttable", "qtxml"):
         if m in pyqt_modules:
