@@ -234,6 +234,8 @@ void Uic::createFormImpl( const QDomElement &e )
     }
 
     // includes for child widgets
+    bool need_axwidget = FALSE;
+
     for ( it = tags.begin(); it != tags.end(); ++it ) {
 	nl = e.parentNode().toElement().elementsByTagName( *it );
 	for ( i = 1; i < (int) nl.length(); i++ ) { // start at 1, 0 is the toplevel widget
@@ -245,6 +247,8 @@ void Uic::createFormImpl( const QDomElement &e )
 	    }
 	    if ( name.mid( 1 ) == "ListView" )
 		globalIncludes += "qheader.h";
+	    else if ( name == "QAxWidget" )
+		need_axwidget = TRUE;
 	    if ( name != objClass ) {
 		int wid = WidgetDatabase::idFromClassName( name );
 		QMap<QString, CustomInclude>::Iterator it = customWidgetIncludes.find( name );
@@ -257,6 +261,12 @@ void Uic::createFormImpl( const QDomElement &e )
     if (globalIncludes.findIndex("qtable.h") >= 0)
 	out << indent << "from qttable import QTable" << endl;
 
+    if (need_axwidget)
+	out << indent << "from qtaxcontainer import QAxWidget" << endl;
+
+    if (globalIncludes.findIndex("qextscintilla.h") >= 0)
+	out << indent << "from qtext import QextScintilla" << endl;
+
     registerDatabases( e );
     dbConnections = unique( dbConnections );
     if ( dbConnections.count() )
@@ -639,25 +649,11 @@ void Uic::createFormImpl( const QDomElement &e )
 		else
 		    receiver = "self." + receiver;
 
+		// We never use the SLOT() macro in case the connection is to a
+		// method of a Python custom widget.
 		out << indent << "self.connect(" << sender
-		    << ",SIGNAL(\"" << signal << "\"),";
-
-		// See if this is a user defined slot.
-		bool isUserSlot = FALSE;
-		for (it = extraSlots.begin(); it != extraSlots.end(); ++it) {
-		    if (*it == slot) {
-			isUserSlot = TRUE;
-			break;
-		    }
-		}
- 
-		if (isUserSlot) {
-		    out << "self." << slot.left(slot.find('('));
-		} else {
-		    out << receiver << ",SLOT(\"" << slot << "\")";
-		}
- 
-		out << ")" << endl;
+		    << ",SIGNAL(\"" << signal << "\")," << receiver << "."
+		    << slot.left(slot.find('(')) << ")" << endl;
 	    }
 	} else if ( n.tagName()  == "tabstops" ) {
 	    // setup tab order
